searchData={"items":[{"type":"module","title":"HumanName","doc":"Documentation for HumanName.","ref":"HumanName.html"},{"type":"function","title":"HumanName.consistent_with?/2","doc":"Performs a comparison of two full names to determine if they are potentially consistent with each other.\n\nIt is important to take into account the nuance of this consistency by reading\nthe [_Defining “consistency”_](https://docs.rs/human_name/latest/human_name/struct.Name.html#defining-consistency) section of the rust library documentation.","ref":"HumanName.html#consistent_with?/2"},{"type":"function","title":"Example - HumanName.consistent_with?/2","doc":"iex> HumanName.consistent_with?(\"Jimmy H Jenkins\", \"Jim Jenkins\")\n      {:ok, true}\n\n      iex> HumanName.consistent_with?(\"John Doe\", \"Johnny J. Doe\")\n      {:ok, true}\n\n      iex> HumanName.consistent_with?(\"Dr. Alibaster Cornelius Juniper III\", \"Alibaster Juniper\")\n      {:ok, true}\n\n      iex> HumanName.consistent_with?(\"Jane Doe\", \"J. Doe\")\n      {:ok, true}\n\n      iex> HumanName.consistent_with?(\"Dr. Alibaster Cornelius Juniper III\", \"Jimmy H Jenkins\")\n      {:ok, false}\n\n      iex> HumanName.consistent_with?(12345, \"John Doe\")\n      {:error, \"No valid names found\"}\n\n      iex> HumanName.consistent_with?(\"fj20i424j\", \"thisisnotavalidname\")\n      {:error, \"No valid name_one found\"}\n\n      iex> HumanName.consistent_with?(\"Jimmy H Jenkins\", \"1234\")\n      {:error, \"No valid name_two found\"}\n\n      iex> HumanName.consistent_with?(nil, nil)\n      {:error, \"No valid names found\"}","ref":"HumanName.html#consistent_with?/2-example"},{"type":"function","title":"HumanName.first_and_last_initials/1","doc":"Returns the combined initials for the first name (given name) and last name (surname).","ref":"HumanName.html#first_and_last_initials/1"},{"type":"function","title":"Example - HumanName.first_and_last_initials/1","doc":"iex> HumanName.first_and_last_initials(\"Jimmy H Jenkins\")\n      {:ok, \"JJ\"}\n\n      iex> HumanName.first_and_last_initials(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"AJ\"}\n\n      iex> HumanName.first_and_last_initials(\"Jane Doe\")\n      {:ok, \"JD\"}\n\n      iex> HumanName.first_and_last_initials(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#first_and_last_initials/1-example"},{"type":"function","title":"HumanName.first_initial/1","doc":"Returns the initial for the first name (given name).","ref":"HumanName.html#first_initial/1"},{"type":"function","title":"Example - HumanName.first_initial/1","doc":"iex> HumanName.first_initial(\"Jimmy H Jenkins\")\n      {:ok, \"J\"}\n\n      iex> HumanName.first_initial(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"A\"}\n\n      iex> HumanName.first_initial(\"Jane Doe\")\n      {:ok, \"J\"}\n\n      iex> HumanName.first_initial(12345)\n      {:error, \"No valid name found\"}\n\n      iex> HumanName.first_initial(\"\")\n      {:error, \"No valid name found\"}\n\n      iex> HumanName.first_initial(nil)\n      {:error, \"No valid name found\"}","ref":"HumanName.html#first_initial/1-example"},{"type":"function","title":"HumanName.first_initial_last/1","doc":"Returns the initial for the first name (given name) and the full last name (surname).","ref":"HumanName.html#first_initial_last/1"},{"type":"function","title":"Example - HumanName.first_initial_last/1","doc":"iex> HumanName.first_initial_last(\"Jimmy H Jenkins\")\n      {:ok, \"J. Jenkins\"}\n\n      iex> HumanName.first_initial_last(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"A. Juniper\"}\n\n      iex> HumanName.first_initial_last(\"Jane Doe\")\n      {:ok, \"J. Doe\"}\n\n      iex> HumanName.first_initial_last(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#first_initial_last/1-example"},{"type":"function","title":"HumanName.first_name/1","doc":"Returns just the formatted first name (given name).","ref":"HumanName.html#first_name/1"},{"type":"function","title":"Example - HumanName.first_name/1","doc":"iex> HumanName.first_name(\"Jimmy H Jenkins\")\n      {:ok, \"Jimmy\"}\n\n      iex> HumanName.first_name(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"Alibaster\"}\n\n      iex> HumanName.first_name(\"Jane Doe\")\n      {:ok, \"Jane\"}\n\n      iex> HumanName.first_name(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#first_name/1-example"},{"type":"function","title":"HumanName.initials/1","doc":"","ref":"HumanName.html#initials/1"},{"type":"function","title":"HumanName.last_initial/1","doc":"Returns just the formatted last name (surname).","ref":"HumanName.html#last_initial/1"},{"type":"function","title":"Example - HumanName.last_initial/1","doc":"iex> HumanName.last_initial(\"Jimmy H Jenkins\")\n      {:ok, \"J\"}\n\n      iex> HumanName.last_initial(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"J\"}\n\n      iex> HumanName.last_initial(\"Jane Doe\")\n      {:ok, \"D\"}\n\n      iex> HumanName.last_initial(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#last_initial/1-example"},{"type":"function","title":"HumanName.last_name/1","doc":"Returns just the formatted last name (surname).","ref":"HumanName.html#last_name/1"},{"type":"function","title":"Example - HumanName.last_name/1","doc":"iex> HumanName.last_name(\"Jimmy H Jenkins\")\n      {:ok, \"Jenkins\"}\n\n      iex> HumanName.last_name(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"Juniper\"}\n\n      iex> HumanName.last_name(\"Jane Doe\")\n      {:ok, \"Doe\"}\n\n      iex> HumanName.last_name(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#last_name/1-example"},{"type":"function","title":"HumanName.middle_initials/1","doc":"Returns the middle initial(s) for a provided full name.","ref":"HumanName.html#middle_initials/1"},{"type":"function","title":"Example - HumanName.middle_initials/1","doc":"iex> HumanName.middle_initials(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"C\"}\n\n      iex> HumanName.middle_initials(\"Jimmy H Jenkins\")\n      {:ok, \"H\"}\n\n      iex> HumanName.middle_initials(\"Jane Dorothy Doe\")\n      {:ok, \"D\"}\n\n      iex> HumanName.middle_initials(\"Jimmy Jenkins\")\n      {:error, \"No middle initials found\"}\n\n      iex> HumanName.middle_initials(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#middle_initials/1-example"},{"type":"function","title":"HumanName.middle_name/1","doc":"Returns the inferred middle name for a provided full name.","ref":"HumanName.html#middle_name/1"},{"type":"function","title":"Example - HumanName.middle_name/1","doc":"iex> HumanName.middle_name(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"Cornelius\"}\n\n      iex> HumanName.middle_name(\"Jane Dorothy Doe\")\n      {:ok, \"Dorothy\"}\n\n      iex> HumanName.middle_name(\"Jimmy H Jenkins\")\n      {:error, \"No middle name found\"}\n\n      iex> HumanName.middle_name(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#middle_name/1-example"},{"type":"function","title":"HumanName.normalize/1","doc":"Returns a formatted version of just the first (given) and last (surname) names.","ref":"HumanName.html#normalize/1"},{"type":"function","title":"Example - HumanName.normalize/1","doc":"iex> HumanName.normalize(\"Jimmy H Jenkins\")\n      {:ok, \"Jimmy Jenkins\"}\n\n      iex> HumanName.normalize(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"Alibaster Juniper\"}\n\n      iex> HumanName.normalize(\"fred mccalister  \")\n      {:ok, \"Fred McCalister\"}\n\n      iex> HumanName.normalize(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#normalize/1-example"},{"type":"function","title":"HumanName.normalize_full/1","doc":"Returns a formatted version of the entire name.","ref":"HumanName.html#normalize_full/1"},{"type":"function","title":"Example - HumanName.normalize_full/1","doc":"iex> HumanName.normalize_full(\"JIMMY H JENKINS\")\n      {:ok, \"Jimmy H. Jenkins\"}\n\n      iex> HumanName.normalize_full(\"Dr. Alibaster Cornelius Juniper III\")\n      {:ok, \"Alibaster Cornelius Juniper, III\"}\n\n      iex> HumanName.normalize_full(\"fred mccalister  \")\n      {:ok, \"Fred McCalister\"}\n\n      iex> HumanName.normalize_full(\"\")\n      {:error, \"No valid name found\"}","ref":"HumanName.html#normalize_full/1-example"},{"type":"extras","title":"HumanName","doc":"# HumanName\n\n[![CI](https://github.com/amokan/human_name/actions/workflows/ci.yaml/badge.svg?branch=main)](https://github.com/amokan/human_name/actions/workflows/ci.yaml)\n[![Hex.pm](https://img.shields.io/hexpm/v/human_name.svg)](https://hex.pm/packages/human_name)\n[![Coverage Status](https://coveralls.io/repos/github/amokan/human_name/badge.svg?branch=main)](https://coveralls.io/github/amokan/human_name?branch=main)\n\nElixir wrapper for [David Judd's](https://github.com/djudd) excellent [human-name](https://crates.io/crates/human_name) crate implemented as a BEAM-friendly Rust NIF.\n\nThe API implemented for use in Elixir/Erlang does not cover every aspect of the Rust library. Feel free to open a PR for contributions.","ref":"readme.html"},{"type":"extras","title":"Installation - HumanName","doc":"This package can be installed by adding `human_name` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:human_name, \"~> 0.6.0\"}\n  ]\nend\n```\n\nBy default **you do not need Rust installed** because the lib will try to download a precompiled NIF file.\n\nIn case you want to force compilation set the\n`HUMAN_NAME_BUILD` environment variable to `true` or `1`.\n\nTo run tests locally, you could do a `HUMAN_NAME_BUILD=1 mix test`.\n\nAlternatively you can also set the application env `:build_from_source` to `true` in order to force the build:\n\n```elixir\nconfig :human_name, HumanName, build_from_source: true\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - HumanName","doc":"```elixir\niex> HumanName.consistent_with?(\"Jimmy H Jenkins\", \"Jim Jenkins\")\n{:ok, true}\n\niex> HumanName.first_and_last_initials(\"Dr. Alibaster Cornelius Juniper III\")\n{:ok, \"AJ\"}\n\niex> HumanName.first_initial(\"Dr. Alibaster Cornelius Juniper III\")\n{:ok, \"A\"}\n\niex> HumanName.first_initial_last(\"Jimmy H Jenkins\")\n{:ok, \"J. Jenkins\"}\n\niex> HumanName.first_name(\"Dr. Alibaster Cornelius Juniper III\")\n{:ok, \"Alibaster\"}\n\niex> HumanName.middle_initials(\"Dr. Alibaster Cornelius Juniper III\")\n{:ok, \"C\"}\n\niex> HumanName.middle_name(\"Dr. Alibaster Cornelius Juniper III\")\n{:ok, \"Cornelius\"}\n\niex> HumanName.last_initial(\"Jimmy H Jenkins\")\n{:ok, \"J\"}\n\niex> HumanName.last_name(\"Dr. Alibaster Cornelius Juniper III\")\n{:ok, \"Juniper\"}\n\niex> HumanName.normalize(\"Dr. Alibaster Cornelius Juniper III\")\n{:ok, \"Alibaster Juniper\"}\n\niex> HumanName.normalize_full(\"JIMMY H JENKINS\")\n{:ok, \"Jimmy H. Jenkins\"}\n```\n\n----","ref":"readme.html#usage"},{"type":"extras","title":"License - HumanName","doc":"MIT License\n\nSee the [license file](LICENSE.txt) for details.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.6.0 (2024-10-07) - Changelog","doc":"* Updated crate for `rustler` (_0.34.0_).\n* Contributions from @lessless (_and @rogerbooth_):\n  * Added `HumanName.consistent_with?/2`.\n  * Added `HumanName.first_and_last_initials/1`.\n  * Added `HumanName.middle_name/1`.\n  * Added `HumanName.middle_initials/1`.\n* Added `HumanName.last_initial/1`.\n* Depreciation message added for `HumanName.initials/1`.\n* General cleanup and additions to the doc tests.\n* Dependency updates for `ex_doc`, `excoveralls`, `rustler` and `rustler_precompiled`.","ref":"changelog.html#v0-6-0-2024-10-07"},{"type":"extras","title":"v0.5.0 (2024-03-24) - Changelog","doc":"* Updated crates for `human_name` (_2.0.3_) and `rustler` (_0.29.1_).\n* Dependency updates for `ex_doc`, `excoveralls`, `rustler` and `rustler_precompiled`.","ref":"changelog.html#v0-5-0-2024-03-24"},{"type":"extras","title":"v0.4.3 (2023-07-22) - Changelog","doc":"* Updated crates for `human_name` (_2.0.2_) and `rustler` (_0.29.1_).\n* Dependency updates for `ex_doc`, `excoveralls`, `rustler` and `rustler_precompiled`.","ref":"changelog.html#v0-4-3-2023-07-22"},{"type":"extras","title":"v0.4.2 (2023-02-17) - Changelog","doc":"* Dependency updates for `rustler`, `rustler_precompiled` and `excoveralls`.","ref":"changelog.html#v0-4-2-2023-02-17"},{"type":"extras","title":"v0.4.1 (2022-12-15) - Changelog","doc":"* Minor dependency updates for `rustler_precompiled`, `ex_doc`, and `excoveralls`.","ref":"changelog.html#v0-4-1-2022-12-15"},{"type":"extras","title":"v0.4.0 (2022-10-14) - Changelog","doc":"* Updated `human_name` crate to v2.0.1 and updated `rustler` crate.\n* Updated `rustler` and `rustler_precompiled` mix dependencies.\n* Changed `HumanName.Native` return to `:erlang.nif_error/1`.","ref":"changelog.html#v0-4-0-2022-10-14"},{"type":"extras","title":"v0.3.0 (2022-08-01) - Changelog","doc":"* Updated `human_name` crate to v1.4.1.","ref":"changelog.html#v0-3-0-2022-08-01"},{"type":"extras","title":"v0.2.5 (2022-07-21) - Changelog","doc":"* Updated `human_name` crate to v1.3.2.","ref":"changelog.html#v0-2-5-2022-07-21"},{"type":"extras","title":"v0.2.4 (2022-07-16) - Changelog","doc":"* Updated `human_name` crate to v1.2.1.","ref":"changelog.html#v0-2-4-2022-07-16"},{"type":"extras","title":"v0.2.2 (2022-04-29) - Changelog","doc":"* Updated `rustler_precompiled` and `ex_doc` dependencies.","ref":"changelog.html#v0-2-2-2022-04-29"},{"type":"extras","title":"v0.2.0 (2022-03-27) - Changelog","doc":"* Now [`rustler_precompiled`](https://hex.pm/packages/rustler_precompiled) as dependency.","ref":"changelog.html#v0-2-0-2022-03-27"},{"type":"extras","title":"v0.1.2 (2021-09-18) - Changelog","doc":"* Fixed `mix.exs` file to include the rust source files and cargo config","ref":"changelog.html#v0-1-2-2021-09-18"},{"type":"extras","title":"v0.1.1 (2021-09-18) - Changelog","doc":"* Fix problem with hex not getting the full bundle","ref":"changelog.html#v0-1-1-2021-09-18"},{"type":"extras","title":"v0.1.0 (2021-09-18) - Changelog","doc":"* Initial release","ref":"changelog.html#v0-1-0-2021-09-18"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Adam Mokan\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}